==> kubernetes-model-core-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FCVolumeSourceFluent<A extends FCVolumeSourceFluent<A>> extends Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToTargetWWNs(int index,String item);
    public A setToTargetWWNs(int index,String item);
    public A addToTargetWWNs(String... items);
    public A addAllToTargetWWNs(Collection<String> items);
    public A removeFromTargetWWNs(String... items);
    public A removeAllFromTargetWWNs(Collection<String> items);
    public List<String> getTargetWWNs();
    public String getTargetWWN(int index);
    public String getFirstTargetWWN();
    public String getLastTargetWWN();
    public String getMatchingTargetWWN(Predicate<String> predicate);
    public Boolean hasMatchingTargetWWN(Predicate<String> predicate);
    public A withTargetWWNs(List<String> targetWWNs);
    public A withTargetWWNs(String... targetWWNs);
    public Boolean hasTargetWWNs();
    public A addNewTargetWWN(String arg1);
    public A addNewTargetWWN(StringBuilder arg1);
    public A addNewTargetWWN(StringBuffer arg1);
    public A addToWwids(int index,String item);
    public A setToWwids(int index,String item);
    public A addToWwids(String... items);
    public A addAllToWwids(Collection<String> items);
    public A removeFromWwids(String... items);
    public A removeAllFromWwids(Collection<String> items);
    public List<String> getWwids();
    public String getWwid(int index);
    public String getFirstWwid();
    public String getLastWwid();
    public String getMatchingWwid(Predicate<String> predicate);
    public Boolean hasMatchingWwid(Predicate<String> predicate);
    public A withWwids(List<String> wwids);
    public A withWwids(String... wwids);
    public Boolean hasWwids();
    public A addNewWwid(String arg1);
    public A addNewWwid(StringBuilder arg1);
    public A addNewWwid(StringBuffer arg1);
}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface FCVolumeSourceFluent<A extends FCVolumeSourceFluent<A>> extends Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public A withNewLun(int arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToTargetWWNs(int index,String item);
    public A setToTargetWWNs(int index,String item);
    public A addToTargetWWNs(String... items);
    public A addAllToTargetWWNs(Collection<String> items);
    public A removeFromTargetWWNs(String... items);
    public A removeAllFromTargetWWNs(Collection<String> items);
    public List<String> getTargetWWNs();
    public String getTargetWWN(int index);
    public String getFirstTargetWWN();
    public String getLastTargetWWN();
    public String getMatchingTargetWWN(Predicate<String> predicate);
    public Boolean hasMatchingTargetWWN(Predicate<String> predicate);
    public A withTargetWWNs(List<String> targetWWNs);
    public A withTargetWWNs(String... targetWWNs);
    public Boolean hasTargetWWNs();
    public A addNewTargetWWN(StringBuilder arg1);
    public A addNewTargetWWN(int[] arg1,int arg2,int arg3);
    public A addNewTargetWWN(char[] arg1);
    public A addNewTargetWWN(StringBuffer arg1);
    public A addNewTargetWWN(byte[] arg1,int arg2);
    public A addNewTargetWWN(byte[] arg1);
    public A addNewTargetWWN(char[] arg1,int arg2,int arg3);
    public A addNewTargetWWN(byte[] arg1,int arg2,int arg3);
    public A addNewTargetWWN(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewTargetWWN(String arg1);
    public A addToWwids(int index,String item);
    public A setToWwids(int index,String item);
    public A addToWwids(String... items);
    public A addAllToWwids(Collection<String> items);
    public A removeFromWwids(String... items);
    public A removeAllFromWwids(Collection<String> items);
    public List<String> getWwids();
    public String getWwid(int index);
    public String getFirstWwid();
    public String getLastWwid();
    public String getMatchingWwid(Predicate<String> predicate);
    public Boolean hasMatchingWwid(Predicate<String> predicate);
    public A withWwids(List<String> wwids);
    public A withWwids(String... wwids);
    public Boolean hasWwids();
    public A addNewWwid(StringBuilder arg1);
    public A addNewWwid(int[] arg1,int arg2,int arg3);
    public A addNewWwid(char[] arg1);
    public A addNewWwid(StringBuffer arg1);
    public A addNewWwid(byte[] arg1,int arg2);
    public A addNewWwid(byte[] arg1);
    public A addNewWwid(char[] arg1,int arg2,int arg3);
    public A addNewWwid(byte[] arg1,int arg2,int arg3);
    public A addNewWwid(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewWwid(String arg1);
}
